@@ -14,11 +14,11 @@
 # under the License.
 
 from gnocchiclient import client
+from gnocchiclient import exceptions
 from oslo_log import log
 from oslo_serialization import jsonutils
 
 from aodh.evaluator import threshold
-from aodh.i18n import _LW
 from aodh import keystone_client
 
 LOG = log.getLogger(__name__)
@@ -48,6 +48,9 @@ class GnocchiBase(threshold.ThresholdEvaluator):
         LOG.debug('sanitize stats %s', statistics)
         statistics = [stats[VALUE] for stats in statistics
                       if stats[GRANULARITY] == rule['granularity']]
+        if not statistics:
+            raise threshold.InsufficientDataError(
+                "No datapoint for granularity %s" % rule['granularity'], [])
         statistics = statistics[-rule['evaluation_periods']:]
         LOG.debug('pruned statistics to %d', len(statistics))
         return statistics
@@ -58,14 +61,31 @@ class GnocchiResourceThresholdEvaluator(GnocchiBase):
         try:
             return self._gnocchi_client.metric.get_measures(
                 metric=rule['metric'],
-                granularity=rule['granularity'],
                 start=start, stop=end,
                 resource_id=rule['resource_id'],
                 aggregation=rule['aggregation_method'])
+        except exceptions.MetricNotFound:
+            raise threshold.InsufficientDataError(
+                'metric %s for resource %s does not exists' %
+                (rule['metric'], rule['resource_id']), [])
+        except exceptions.ResourceNotFound:
+            raise threshold.InsufficientDataError(
+                'resource %s does not exists' % rule['resource_id'], [])
+        except exceptions.NotFound:
+            # TODO(sileht): gnocchiclient should raise a explicit
+            # exception for AggregationNotFound, this API endpoint
+            # can only raise 3 different 404, so we are safe to
+            # assume this is an AggregationNotFound for now.
+            raise threshold.InsufficientDataError(
+                'aggregation %s does not exist for '
+                'metric %s of resource %s' % (rule['aggregation_method'],
+                                              rule['metric'],
+                                              rule['resource_id']),
+                [])
         except Exception as e:
-            LOG.warning(_LW('alarm stats retrieval failed: %s'),
-                        e)
-            return []
+            msg = 'alarm statistics retrieval failed: %s' % e
+            LOG.warning(msg)
+            raise threshold.InsufficientDataError(msg, [])
 
 
 class GnocchiAggregationMetricsThresholdEvaluator(GnocchiBase):
@@ -81,13 +101,26 @@ class GnocchiAggregationMetricsThresholdEvaluator(GnocchiBase):
             #   https://bugs.launchpad.net/gnocchi/+bug/1479429
             return self._gnocchi_client.metric.aggregation(
                 metrics=rule['metrics'],
-                granularity=rule['granularity'],
                 start=start, stop=end,
                 aggregation=rule['aggregation_method'],
                 needed_overlap=0)
+        except exceptions.MetricNotFound:
+            raise threshold.InsufficientDataError(
+                'At least of metrics in %s does not exist' %
+                rule['metrics'], [])
+        except exceptions.NotFound:
+            # TODO(sileht): gnocchiclient should raise a explicit
+            # exception for AggregationNotFound, this API endpoint
+            # can only raise 3 different 404, so we are safe to
+            # assume this is an AggregationNotFound for now.
+            raise threshold.InsufficientDataError(
+                'aggregation %s does not exist for at least one '
+                'metrics in %s' % (rule['aggregation_method'],
+                                   rule['metrics']), [])
         except Exception as e:
-            LOG.warning(_LW('alarm stats retrieval failed: %s'), e)
-            return []
+            msg = 'alarm statistics retrieval failed: %s' % e
+            LOG.warning(msg)
+            raise threshold.InsufficientDataError(msg, [])
 
 
 class GnocchiAggregationResourcesThresholdEvaluator(GnocchiBase):
@@ -103,13 +136,24 @@ class GnocchiAggregationResourcesThresholdEvaluator(GnocchiBase):
         try:
             return self._gnocchi_client.metric.aggregation(
                 metrics=rule['metric'],
-                granularity=rule['granularity'],
                 query=jsonutils.loads(rule['query']),
                 resource_type=rule["resource_type"],
                 start=start, stop=end,
                 aggregation=rule['aggregation_method'],
                 needed_overlap=0,
             )
+        except exceptions.MetricNotFound:
+            raise threshold.InsufficientDataError(
+                'metric %s does not exists' % rule['metric'], [])
+        except exceptions.NotFound:
+            # TODO(sileht): gnocchiclient should raise a explicit
+            # exception for AggregationNotFound, this API endpoint
+            # can only raise 3 different 404, so we are safe to
+            # assume this is an AggregationNotFound for now.
+            raise threshold.InsufficientDataError(
+                'aggregation %s does not exist for at least one '
+                'metric of the query' % rule['aggregation_method'], [])
         except Exception as e:
-            LOG.warning(_LW('alarm stats retrieval failed: %s'), e)
-            return []
+            msg = 'alarm statistics retrieval failed: %s' % e
+            LOG.warning(msg)
+            raise threshold.InsufficientDataError(msg, [])
