@@ -27,11 +27,11 @@ from oslo_utils import timeutils
 import six
 from sqlalchemy import asc
 from sqlalchemy import desc
+from sqlalchemy.engine import url as sqlalchemy_url
 from sqlalchemy import func
 from sqlalchemy.orm import exc
 
 import aodh
-from aodh.i18n import _LI
 from aodh import storage
 from aodh.storage import base
 from aodh.storage import models as alarm_api_models
@@ -72,9 +72,19 @@ class Connection(base.Connection):
         # oslo.db doesn't support options defined by Aodh
         for opt in storage.OPTS:
             options.pop(opt.name, None)
-        self._engine_facade = db_session.EngineFacade(url, **options)
+        self._engine_facade = db_session.EngineFacade(self.dress_url(url),
+                                                      **options)
         self.conf = conf
 
+    @staticmethod
+    def dress_url(url):
+        # If no explicit driver has been set, we default to pymysql
+        if url.startswith("mysql://"):
+            url = sqlalchemy_url.make_url(url)
+            url.drivername = "mysql+pymysql"
+            return str(url)
+        return url
+
     def disconnect(self):
         self._engine_facade.get_engine().dispose()
 
@@ -82,7 +92,7 @@ class Connection(base.Connection):
         cfg = config.Config(
             "%s/sqlalchemy/alembic/alembic.ini" % os.path.dirname(__file__))
         cfg.set_main_option('sqlalchemy.url',
-                            self.conf.database.connection.replace("%", "%%"))
+                            self.conf.database.connection)
         return cfg
 
     def upgrade(self, nocreate=False):
@@ -137,6 +147,7 @@ class Connection(base.Connection):
                                       project_id=row.project_id,
                                       state=row.state,
                                       state_timestamp=row.state_timestamp,
+                                      state_reason=row.state_reason,
                                       ok_actions=row.ok_actions,
                                       alarm_actions=row.alarm_actions,
                                       insufficient_data_actions=(
@@ -392,5 +403,5 @@ class Connection(base.Connection):
             deleted_rows = (session.query(models.AlarmChange)
                             .filter(models.AlarmChange.timestamp < valid_start)
                             .delete())
-            LOG.info(_LI("%d alarm histories are removed from database"),
+            LOG.info("%d alarm histories are removed from database",
                      deleted_rows)
