@@ -33,12 +33,15 @@ class AodhTempestPlugin(plugins.TempestPlugin):
 
     def register_opts(self, conf):
         config.register_opt_group(conf,
-                                  tempest_config.service_available_group,
-                                  tempest_config.ServiceAvailableGroup)
+                                  config.service_available_group,
+                                  tempest_config.service_option)
         config.register_opt_group(conf,
                                   tempest_config.alarming_group,
                                   tempest_config.AlarmingGroup)
 
     def get_opt_lists(self):
-        return [(tempest_config.alarming_group.name,
-                 tempest_config.AlarmingGroup)]
+        return [
+            (tempest_config.alarming_group.name,
+             tempest_config.AlarmingGroup),
+            ('service_available', tempest_config.service_option)
+        ]
