@@ -14,13 +14,13 @@
 # under the License.
 
 import datetime
+import fixtures
 import unittest
 
 from gnocchiclient import exceptions
 import mock
 from oslo_utils import timeutils
 from oslo_utils import uuidutils
-from oslotest import mockpatch
 import pytz
 import six
 from six import moves
@@ -33,7 +33,7 @@ from aodh.tests.unit.evaluator import base
 
 class TestGnocchiEvaluatorBase(base.TestEvaluatorBase):
     def setUp(self):
-        self.client = self.useFixture(mockpatch.Patch(
+        self.client = self.useFixture(fixtures.MockPatch(
             'aodh.evaluator.gnocchi.client'
         )).mock.Client.return_value
         self.prepared_alarms = [
@@ -45,6 +45,7 @@ class TestGnocchiEvaluatorBase(base.TestEvaluatorBase):
                          project_id='snafu',
                          alarm_id=uuidutils.generate_uuid(),
                          state='insufficient data',
+                         state_reason='insufficient data',
                          state_timestamp=constants.MIN_DATETIME,
                          timestamp=constants.MIN_DATETIME,
                          insufficient_data_actions=[],
@@ -69,6 +70,7 @@ class TestGnocchiEvaluatorBase(base.TestEvaluatorBase):
                          user_id='foobar',
                          project_id='snafu',
                          state='insufficient data',
+                         state_reason='insufficient data',
                          state_timestamp=constants.MIN_DATETIME,
                          timestamp=constants.MIN_DATETIME,
                          insufficient_data_actions=[],
@@ -94,6 +96,7 @@ class TestGnocchiEvaluatorBase(base.TestEvaluatorBase):
                          project_id='snafu',
                          alarm_id=uuidutils.generate_uuid(),
                          state='insufficient data',
+                         state_reason='insufficient data',
                          state_timestamp=constants.MIN_DATETIME,
                          timestamp=constants.MIN_DATETIME,
                          insufficient_data_actions=[],
@@ -147,8 +150,8 @@ class TestGnocchiEvaluatorBase(base.TestEvaluatorBase):
         expected = [mock.call(
             alarm,
             'ok',
-            ('%d datapoints are unknown'
-             % alarm.rule['evaluation_periods']),
+            ('No datapoint for granularity %s'
+             % alarm.rule['granularity']),
             self._reason_data('unknown',
                               alarm.rule['evaluation_periods'],
                               None))
@@ -186,7 +189,6 @@ class TestGnocchiResourceThresholdEvaluate(TestGnocchiEvaluatorBase):
 
         self.assertEqual(
             [mock.call.get_measures(aggregation='mean', metric='cpu_util',
-                                    granularity=60,
                                     resource_id='my_instance',
                                     start=start_alarm, stop=end)],
             self.client.metric.mock_calls)
@@ -327,7 +329,6 @@ class TestGnocchiAggregationMetricsThresholdEvaluate(TestGnocchiEvaluatorBase):
                                    metrics=[
                                        '0bb1604d-1193-4c0a-b4b8-74b170e35e83',
                                        '9ddc209f-42f8-41e1-b8f1-8804f59c4053'],
-                                   granularity=300,
                                    needed_overlap=0,
                                    start=start_alarm, stop=end)],
             self.client.metric.mock_calls)
@@ -445,7 +446,6 @@ class TestGnocchiAggregationResourcesThresholdEvaluate(
         end = "2015-01-26T12:57:00"
         self.assertEqual(
             [mock.call.aggregation(aggregation='mean', metrics='cpu_util',
-                                   granularity=50,
                                    needed_overlap=0,
                                    query={"=": {"server_group":
                                           "my_autoscaling_group"}},
